@@ -71,7 +71,6 @@ G_DEFINE_TYPE (PanelDesktopMenuItem, panel_desktop_menu_item, PANEL_TYPE_IMAGE_M
 
 struct _PanelPlaceMenuItemPrivate {
 	GtkWidget   *menu;
-	PanelWidget *panel;
 	GSettings   *settings;
 
 	GtkRecentManager *recent_manager;
@@ -92,7 +91,6 @@ struct _PanelPlaceMenuItemPrivate {
 
 struct _PanelDesktopMenuItemPrivate {
 	GtkWidget   *menu;
-	PanelWidget *panel;
 	GtkIconSize  icon_size;
 };
 
@@ -137,14 +135,11 @@ activate_desktop_uri (GtkWidget *menuitem,
 }
 
 static GtkWidget *
-panel_menu_item_desktop_new (char      *path,
-			     char      *force_name,
-			     gboolean   use_icon)
+panel_menu_item_desktop_new (const gchar *desktop_file)
 {
 	GKeyFile  *key_file;
 	gboolean   loaded;
 	GtkWidget *item;
-	char      *path_freeme;
 	char      *full_path;
 	char      *uri;
 	char      *type;
@@ -154,41 +149,24 @@ panel_menu_item_desktop_new (char      *path,
 	char      *name;
 	char      *comment;
 
-	path_freeme = NULL;
-
+	full_path = NULL;
 	key_file = g_key_file_new ();
 
-	if (g_path_is_absolute (path)) {
-		loaded = g_key_file_load_from_file (key_file, path,
-						    G_KEY_FILE_NONE, NULL);
-		full_path = path;
-	} else {
+	{
 		char *lookup_file;
-		char *desktop_path;
-
-		if (!g_str_has_suffix (path, ".desktop")) {
-			desktop_path = g_strconcat (path, ".desktop", NULL);
-		} else {
-			desktop_path = path;
-		}
 
 		lookup_file = g_strconcat ("applications", G_DIR_SEPARATOR_S,
-					   desktop_path, NULL);
+					   desktop_file, NULL);
 		loaded = g_key_file_load_from_data_dirs (key_file, lookup_file,
-							 &path_freeme,
+							 &full_path,
 							 G_KEY_FILE_NONE,
 							 NULL);
-		full_path = path_freeme;
 		g_free (lookup_file);
-
-		if (desktop_path != path)
-			g_free (desktop_path);
 	}
 
 	if (!loaded) {
 		g_key_file_free (key_file);
-		if (path_freeme)
-			g_free (path_freeme);
+		g_free (full_path);
 		return NULL;
 	}
 
@@ -196,8 +174,7 @@ panel_menu_item_desktop_new (char      *path,
 	type = panel_key_file_get_string (key_file, "Type");
 	if (!type) {
 		g_key_file_free (key_file);
-		if (path_freeme)
-			g_free (path_freeme);
+		g_free (full_path);
 		return NULL;
 	}
 	is_application = (strcmp (type, "Application") == 0);
@@ -217,8 +194,7 @@ panel_menu_item_desktop_new (char      *path,
 				 * program appears, but that's really complex
 				 * for not a huge benefit */
 				g_key_file_free (key_file);
-				if (path_freeme)
-					g_free (path_freeme);
+				g_free (full_path);
 				return NULL;
 			}
 
@@ -229,17 +205,9 @@ panel_menu_item_desktop_new (char      *path,
 	/* Now, simply build the menu item */
 	icon    = panel_key_file_get_locale_string (key_file, "Icon");
 	comment = panel_key_file_get_locale_string (key_file, "Comment");
+	name = panel_key_file_get_locale_string (key_file, "Name");
 
-	if (PANEL_GLIB_STR_EMPTY (force_name))
-		name = panel_key_file_get_locale_string (key_file, "Name");
-	else
-		name = g_strdup (force_name);
-
-	if (use_icon) {
-		item = panel_image_menu_item_new2 ();
-        } else {
-		item = panel_image_menu_item_new ();
-	}
+	item = panel_image_menu_item_new ();
 
 	setup_menu_item_with_icon (item, panel_menu_icon_get_size (),
 				   icon, NULL, name);
@@ -260,17 +228,10 @@ panel_menu_item_desktop_new (char      *path,
 
 	g_key_file_free (key_file);
 
-	if (icon)
-		g_free (icon);
-
-	if (name)
-		g_free (name);
-
-	if (comment)
-		g_free (comment);
-
-	if (path_freeme)
-		g_free (path_freeme);
+	g_free (icon);
+	g_free (name);
+	g_free (comment);
+	g_free (full_path);
 
 	return item;
 }
@@ -338,13 +299,6 @@ panel_menu_items_create_action_item_full (PanelActionButtonType  action_type,
 	return item;
 }
 
-static GtkWidget *
-panel_menu_items_create_action_item (PanelActionButtonType action_type)
-{
-	return panel_menu_items_create_action_item_full (action_type,
-							 NULL, NULL, FALSE);
-}
-
 static void
 panel_menu_item_activate_switch_user (GtkWidget *menuitem,
 				      gpointer   user_data)
@@ -978,19 +932,19 @@ panel_place_menu_item_append_local_gio (PanelPlaceMenuItem *place_item,
 	if (g_slist_length (items) <= MAX_ITEMS_OR_SUBMENU) {
 		add_menu = menu;
 	} else {
-		GtkWidget  *item;
+		GtkWidget  *menu_item;
 
-		item = panel_image_menu_item_new ();
-		setup_menu_item_with_icon (item, panel_menu_icon_get_size (),
+		menu_item = panel_image_menu_item_new ();
+		setup_menu_item_with_icon (menu_item, panel_menu_icon_get_size (),
 					   PANEL_ICON_REMOVABLE_MEDIA,
 					   NULL,
 					   _("Removable Media"));
 
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-		gtk_widget_show (item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+		gtk_widget_show (menu_item);
 
 		add_menu = create_empty_menu ();
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), add_menu);
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), add_menu);
 	}
 
 	for (sl = items; sl; sl = sl->next) {
@@ -1164,18 +1118,9 @@ panel_place_menu_item_create_menu (PanelPlaceMenuItem *place_item)
 
 	panel_place_menu_item_append_remote_gio (place_item, places_menu);
 
-	if (panel_is_program_in_path ("nautilus-connect-server")) {
-		item = panel_menu_items_create_action_item (PANEL_ACTION_CONNECT_SERVER);
-		if (item != NULL)
-			gtk_menu_shell_append (GTK_MENU_SHELL (places_menu),
-					       item);
-	}
-
 	add_menu_separator (places_menu);
 
-	item = panel_menu_item_desktop_new ("gnome-search-tool.desktop",
-					    NULL,
-					    FALSE);
+	item = panel_menu_item_desktop_new ("gnome-search-tool.desktop");
 	if (item)
 		gtk_menu_shell_append (GTK_MENU_SHELL (places_menu), item);
 
@@ -1251,8 +1196,7 @@ panel_desktop_menu_item_create_menu (PanelDesktopMenuItem *desktop_item,
 
 	/* Do not force the string like in gnome-shell, but just use the one
 	 * from the .desktop file */
-	item = panel_menu_item_desktop_new ("gnome-control-center.desktop",
-					    NULL, FALSE);
+	item = panel_menu_item_desktop_new ("gnome-control-center.desktop");
 	if (item)
 		gtk_menu_shell_append (GTK_MENU_SHELL (desktop_menu), item);
 
@@ -1543,28 +1487,6 @@ panel_desktop_menu_item_new (gboolean use_image,
 	return GTK_WIDGET (menuitem);
 }
 
-void
-panel_place_menu_item_set_panel (GtkWidget   *item,
-				 PanelWidget *panel)
-{
-	PanelPlaceMenuItem *place_item;
-
-	place_item = PANEL_PLACE_MENU_ITEM (item);
-
-	place_item->priv->panel = panel;
-}
-
-void
-panel_desktop_menu_item_set_panel (GtkWidget   *item,
-				   PanelWidget *panel)
-{
-	PanelDesktopMenuItem *desktop_item;
-
-	desktop_item = PANEL_DESKTOP_MENU_ITEM (item);
-
-	desktop_item->priv->panel = panel;
-}
-
 static void
 panel_menu_items_lock_logout_separator_notified (PanelLockdown *lockdown,
 						 gpointer       user_data)
